### R code from vignette source 'LaplacesDemonTutorial.Stex'

###################################################
### code chunk number 1: LaplacesDemonTutorial.Stex:64-65 (eval = FALSE)
###################################################
## install.packages("LaplacesDemon")


###################################################
### code chunk number 2: LaplacesDemonTutorial.Stex:70-71
###################################################
library(LaplacesDemon)


###################################################
### code chunk number 3: LaplacesDemonTutorial.Stex:77-86
###################################################
data(demonsnacks)
N <- NROW(demonsnacks)
J <- NCOL(demonsnacks)
y <- log(demonsnacks$Calories)
X <- cbind(1, as.matrix(demonsnacks[,c(1,3:10)]))
for (j in 2:J) {X[,j] <- CenterScale(X[,j])}
mon.names <- c("LP","sigma")
parm.names <- as.parm.names(list(beta=rep(0,J), log.sigma=0))
MyData <- list(J=J, X=X, mon.names=mon.names, parm.names=parm.names, y=y)


###################################################
### code chunk number 4: LaplacesDemonTutorial.Stex:110-127
###################################################
Model <- function(parm, Data)
     {
     ### Parameters
     beta <- parm[1:Data$J]
     sigma <- exp(parm[Data$J+1])
     ### Log(Prior Densities)
     beta.prior <- dnormv(beta, 0, 1000, log=TRUE)
     sigma.prior <- dhalfcauchy(sigma, 25, log=TRUE)
     ### Log-Likelihood
     mu <- tcrossprod(beta, Data$X)
     LL <- sum(dnorm(Data$y, mu, sigma, log=TRUE))
     ### Log-Posterior
     LP <- LL + sum(beta.prior) + sigma.prior
     Modelout <- list(LP=LP, Dev=-2*LL, Monitor=c(LP,sigma), yhat=mu,
          parm=parm)
     return(Modelout)
     }


###################################################
### code chunk number 5: LaplacesDemonTutorial.Stex:188-189
###################################################
Initial.Values <- c(rep(0,J), log(1))


###################################################
### code chunk number 6: LaplacesDemonTutorial.Stex:195-196
###################################################
set.seed(666)


###################################################
### code chunk number 7: LaplacesDemonTutorial.Stex:201-202 (eval = FALSE)
###################################################
## help(LaplacesDemon) 


###################################################
### code chunk number 8: LaplacesDemonTutorial.Stex:207-210 (eval = FALSE)
###################################################
## Fit <- LaplacesDemon(Model, Data=MyData, Adaptive=2, 
##      Covar=NULL, DR=0, Gibbs=TRUE, Initial.Values, Iterations=2000,
##      Periodicity=10, Status=100, Thinning=2)


###################################################
### code chunk number 9: LaplacesDemonTutorial.Stex:230-233
###################################################
Fit <- LaplacesDemon(Model, Data=MyData, Adaptive=2, 
     Covar=NULL, DR=0, Gibbs=TRUE, Initial.Values, Iterations=2000,
     Periodicity=10, Status=100, Thinning=2)


###################################################
### code chunk number 10: LaplacesDemonTutorial.Stex:238-239 (eval = FALSE)
###################################################
## str(Fit)


###################################################
### code chunk number 11: LaplacesDemonTutorial.Stex:244-245
###################################################
Fit$Acceptance.Rate


###################################################
### code chunk number 12: LaplacesDemonTutorial.Stex:251-253 (eval = FALSE)
###################################################
## Fit
## print(Fit)


###################################################
### code chunk number 13: LaplacesDemonTutorial.Stex:258-259
###################################################
Fit


###################################################
### code chunk number 14: LaplacesDemonTutorial.Stex:264-265 (eval = FALSE)
###################################################
## Fit$Posterior2


###################################################
### code chunk number 15: LaplacesDemonTutorial.Stex:276-277
###################################################
Consort(Fit)


###################################################
### code chunk number 16: LaplacesDemonTutorial.Stex:286-292
###################################################
Rec.Iterations <- trunc(Fit$Rec.Thinning / Fit$Thinning *
     Fit$Iterations)
Status.temp <- round(Rec.Iterations / (Fit$Minutes *
     Rec.Iterations / Fit$Iterations),0)
if(Status.temp < Rec.Iterations) Rec.Status <- Status.temp
#else Rec.Status <- sqrt(Rec.Iterations)


###################################################
### code chunk number 17: LaplacesDemonTutorial.Stex:297-301
###################################################
Initial.Values <- as.initial.values(Fit)
Fit <- LaplacesDemon(Model, Data=MyData, Adaptive=0,
     Covar=Fit$Covar, DR=0, Gibbs=TRUE, Initial.Values, Iterations=70000,
     Periodicity=0, Status=10000, Thinning=70)


###################################################
### code chunk number 18: LaplacesDemonTutorial.Stex:306-307
###################################################
Consort(Fit)


###################################################
### code chunk number 19: LaplacesDemonTutorial.Stex:315-316
###################################################
BurnIn <- Fit$Rec.BurnIn.Thinned


###################################################
### code chunk number 20: LaplacesDemonTutorial.Stex:318-319 (eval = FALSE)
###################################################
## plot(Fit, BurnIn, MyData, PDF=FALSE, Parms=Fit$Parameters)


###################################################
### code chunk number 21: fig1
###################################################
par(mfrow=c(3,3))
for (j in 1:3){
     plot(BurnIn:Fit$Thinned.Samples,
          Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j],
          type="l", xlab="Iterations", ylab="Value",
          main=MyData$parm.names[j])
     panel.smooth(BurnIn:Fit$Thinned.Samples, 
          Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j], pch="")
     plot(density(Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j]),
          xlab="Value", main=MyData$parm.names[j])
     polygon(density(Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j]),
          col="black", border="black")
     abline(v=0, col="red", lty=2)
     z <- acf(Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j], plot=FALSE)
     se <- 1/sqrt(length(Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j]))
     plot(z$lag, z$acf, ylim=c(min(z$acf,-2*se),1), type="h",
          main=MyData$parm.names[j], xlab="Lag", ylab="Correlation")
     abline(h=(2*se), col="red", lty=2)
     abline(h=(-2*se), col="red", lty=2)
     }


###################################################
### code chunk number 22: fig2
###################################################
par(mfrow=c(3,3))
for (j in 4:6){
     plot(BurnIn:Fit$Thinned.Samples,
          Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j],
          type="l", xlab="Iterations", ylab="Value",
          main=MyData$parm.names[j])
     panel.smooth(BurnIn:Fit$Thinned.Samples, 
          Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j], pch="")
     plot(density(Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j]),
          xlab="Value", main=MyData$parm.names[j])
     polygon(density(Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j]),
          col="black", border="black")
     abline(v=0, col="red", lty=2)
     z <- acf(Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j], plot=FALSE)
     se <- 1/sqrt(length(Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j]))
     plot(z$lag, z$acf, ylim=c(min(z$acf,-2*se),1), type="h",
          main=MyData$parm.names[j], xlab="Lag", ylab="Correlation")
     abline(h=(2*se), col="red", lty=2)
     abline(h=(-2*se), col="red", lty=2)
     }


###################################################
### code chunk number 23: fig3
###################################################
par(mfrow=c(3,3))
for (j in 7:9){
     plot(BurnIn:Fit$Thinned.Samples,
          Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j],
          type="l", xlab="Iterations", ylab="Value",
          main=MyData$parm.names[j])
     panel.smooth(BurnIn:Fit$Thinned.Samples, 
          Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j], pch="")
     plot(density(Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j]),
          xlab="Value", main=MyData$parm.names[j])
     polygon(density(Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j]),
          col="black", border="black")
     abline(v=0, col="red", lty=2)
     z <- acf(Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j], plot=FALSE)
     se <- 1/sqrt(length(Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j]))
     plot(z$lag, z$acf, ylim=c(min(z$acf,-2*se),1), type="h",
          main=MyData$parm.names[j], xlab="Lag", ylab="Correlation")
     abline(h=(2*se), col="red", lty=2)
     abline(h=(-2*se), col="red", lty=2)
     }


###################################################
### code chunk number 24: fig4
###################################################
par(mfrow=c(3,3))
for (j in 10:11){
     plot(BurnIn:Fit$Thinned.Samples,
          Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j],
          type="l", xlab="Iterations", ylab="Value",
          main=MyData$parm.names[j])
     panel.smooth(BurnIn:Fit$Thinned.Samples, 
          Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j], pch="")
     plot(density(Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j]),
          xlab="Value", main=MyData$parm.names[j])
     polygon(density(Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j]),
          col="black", border="black")
     abline(v=0, col="red", lty=2)
     z <- acf(Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j], plot=FALSE)
     se <- 1/sqrt(length(Fit$Posterior1[BurnIn:Fit$Thinned.Samples,j]))
     plot(z$lag, z$acf, ylim=c(min(z$acf,-2*se),1), type="h",
          main=MyData$parm.names[j], xlab="Lag", ylab="Correlation")
     abline(h=(2*se), col="red", lty=2)
     abline(h=(-2*se), col="red", lty=2)
     }
plot(BurnIn:length(Fit$Deviance),
     Fit$Deviance[BurnIn:length(Fit$Deviance)],
     type="l", xlab="Iterations", ylab="Value", main="Deviance")
panel.smooth(BurnIn:length(Fit$Deviance), 
     Fit$Deviance[BurnIn:length(Fit$Deviance)], pch="")
plot(density(Fit$Deviance[BurnIn:length(Fit$Deviance)]),
     xlab="Value", main="Deviance")
polygon(density(Fit$Deviance[BurnIn:length(Fit$Deviance)]),
     col="black", border="black")
abline(v=0, col="red", lty=2)
z <- acf(Fit$Deviance[BurnIn:length(Fit$Deviance)], plot=FALSE)
se <- 1/sqrt(length(Fit$Deviance[BurnIn:length(Fit$Deviance)]))
plot(z$lag, z$acf, ylim=c(min(z$acf,-2*se),1), type="h",
     main="Deviance", xlab="Lag", ylab="Correlation")
abline(h=(2*se), col="red", lty=2)
abline(h=(-2*se), col="red", lty=2)


###################################################
### code chunk number 25: fig5
###################################################
par(mfrow=c(2,3))
JJ <- NCOL(Fit$Monitor); nn <- NROW(Fit$Monitor)
for (j in 1:JJ){
     plot(BurnIn:nn, 
          Fit$Monitor[BurnIn:nn,j],
          type="l", xlab="Iterations", ylab="Value", 
          main=MyData$mon.names[j])
     panel.smooth(BurnIn:nn, 
          Fit$Monitor[BurnIn:nn,j], pch="")
     plot(density(Fit$Monitor[BurnIn:nn,j]), xlab="Value", 
          main=MyData$mon.names[j])
     polygon(density(Fit$Monitor[BurnIn:nn,j]),
          col="black", border="black")
     abline(v=0, col="red", lty=2)
     z <- acf(Fit$Monitor[BurnIn:nn,j], plot=FALSE)
     se <- 1/sqrt(length(Fit$Monitor[BurnIn:nn,j]))
     plot(z$lag, z$acf, ylim=c(min(z$acf,-2*se),1), type="h",
          main=MyData$mon.names[j], xlab="Lag", ylab="Correlation")
     abline(h=(2*se), col="red", lty=2)
     abline(h=(-2*se), col="red", lty=2)
     }


###################################################
### code chunk number 26: LaplacesDemonTutorial.Stex:486-487 (eval = FALSE)
###################################################
## caterpillar.plot(Fit, Parms=1:10)


###################################################
### code chunk number 27: fig6
###################################################
par(mfrow=c(1,1))
caterpillar.plot(Fit, Parms=1:10)


###################################################
### code chunk number 28: LaplacesDemonTutorial.Stex:507-508
###################################################
Pred <- predict(Fit, Model, MyData)


###################################################
### code chunk number 29: LaplacesDemonTutorial.Stex:517-518
###################################################
summary(Pred, Discrep="Chi-Square")


###################################################
### code chunk number 30: LaplacesDemonTutorial.Stex:531-532 (eval = FALSE)
###################################################
## plot(Pred, Style="Density", Rows=1:9)


###################################################
### code chunk number 31: fig7
###################################################
par(mfrow=c(3,3))
for (j in 1:9){
     plot(density(Pred$yhat[j,]), xlab="Value",
          main=paste("Post. Pred. Plot of yhat[", j,
               ",]", sep=""), sub="Black=Density, Red=y")
     polygon(density(Pred$yhat[j,]), col="black", border="black")
     abline(v=Pred$y[j], col="red")
     }


###################################################
### code chunk number 32: LaplacesDemonTutorial.Stex:584-585 (eval = FALSE)
###################################################
## LaplacesDemon


###################################################
### code chunk number 33: LaplacesDemonTutorial.Stex:590-591 (eval = FALSE)
###################################################
## LaplacesDemon:::RWM


